@@ -12,13 +12,26 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from cloudevents.http.event import CloudEvent  # noqa
-from cloudevents.http.event_type import is_binary, is_structured  # noqa
-from cloudevents.http.http_methods import (  # noqa
-    from_http,
+
+from cloudevents.http.conversion import from_dict, from_http, from_json
+from cloudevents.http.event import CloudEvent
+from cloudevents.http.event_type import is_binary, is_structured  # deprecated
+from cloudevents.http.http_methods import (  # deprecated
     to_binary,
     to_binary_http,
     to_structured,
     to_structured_http,
 )
-from cloudevents.http.json_methods import from_json, to_json  # noqa
+
+__all__ = [
+    to_binary,
+    to_structured,
+    from_json,
+    from_http,
+    from_dict,
+    CloudEvent,
+    is_binary,
+    is_structured,
+    to_binary_http,
+    to_structured_http,
+]
